@@ -182,48 +182,6 @@ activity_root_name_by_classification = {
 }
 
 
-class ComponentXType(Enum):
-    """The various inspectortypes supported in the customized task in KE-chain.
-
-    :cvar PANEL: panel
-    :cvar TOOLBAR: toolbar
-    :cvar PROPERTYGRID: propertyGrid
-    :cvar SUPERGRID: superGrid
-    :cvar PAGINATEDSUPERGRID: paginatedSuperGrid
-    :cvar FILTEREDGRID: filteredGrid
-    :cvar DISPLAYFIELD: displayfield
-    :cvar PROPERTYATTACHMENTPREVIEWER: propertyAttachmentViewer
-    :cvar HTMLPANEL: htmlPanel
-    :cvar EXECUTESERVICE: executeService
-    :cvar NOTEBOOKPANEL: notebookPanel
-    :cvar BUTTON: button
-    :cvar MODELVIEWER: modelViewer
-    :cvar CSVGRID: csvGrid
-    :cvar JSONTREE: jsonTree
-    """
-
-    PANEL = "panel"
-    TOOLBAR = "toolbar"
-    PROPERTYGRID = "propertyGrid"
-    SUPERGRID = "superGrid"
-    PAGINATEDSUPERGRID = "paginatedSuperGrid"
-    FILTEREDGRID = "filteredGrid"
-    DISPLAYFIELD = "displayfield"
-    # in 1.13.1
-    PROPERTYATTACHMENTPREVIEWER = "propertyAttachmentViewer"
-    HTMLPANEL = "htmlPanel"
-    EXECUTESERVICE = "executeService"
-    NOTEBOOKPANEL = "notebookPanel"
-    # Issue #279:
-    ACTIVITYNAVIGATIONBAR = "activityNavigationBar"
-
-    # for RND
-    BUTTON = "button"
-    MODELVIEWER = "modelViewer"
-    CSVGRID = "csvGrid"
-    JSONTREE = "jsonTree"
-
-
 class WidgetNames(Enum):
     """The various Names of the Widget that can be configured.
 
@@ -344,12 +302,6 @@ default_metapanel_widget = dict(
     ),
 )
 
-default_activity_customization = dict(
-    ext=dict(
-        widgets=[default_metapanel_widget]
-    )
-)
-
 
 class ActivityStatus(Enum):
     """The various Activity statuses that are accepted by KE-chain.
@@ -409,25 +361,17 @@ class ServiceType(Enum):
 class ServiceEnvironmentVersion(Enum):
     """The acceptable versions of python where services run on.
 
-    :cvar PYTHON_2_7: Service execution environment is a python 2.7 container
-    :cvar PYTHON_3_5: Service execution environment is a python 3.5 container
     :cvar PYTHON_3_6: Service execution environment is a python 3.6 container
     :cvar PYTHON_3_7: Service execution environment is a python 3.7 container
     :cvar PYTHON_3_8: Service execution environment is a python 3.8 container
-    :cvar PYTHON_3_5_NOTEBOOKS: execution environment is a python 3.5 container with jupyter notebook preinstalled
     :cvar PYTHON_3_6_NOTEBOOKS: execution environment is a python 3.6 container with jupyter notebook preinstalled
-    :cvar PYTHON_3_7_NOTEBOOKS: execution environment is a python 3.7 container with jupyter notebook preinstalled
     :cvar PYTHON_3_8_NOTEBOOKS: execution environment is a python 3.8 container with jupyter notebook preinstalled
     """
 
-    PYTHON_2_7 = '2.7'
-    PYTHON_3_5 = '3.5'
     PYTHON_3_6 = '3.6'
     PYTHON_3_7 = '3.7'
     PYTHON_3_8 = '3.8'
-    PYTHON_3_5_NOTEBOOKS = '3.5_notebook'
     PYTHON_3_6_NOTEBOOKS = '3.6_notebook'
-    PYTHON_3_7_NOTEBOOKS = '3.7_notebook'
     PYTHON_3_8_NOTEBOOKS = '3.8_notebook'
 
 
