@@ -2,7 +2,7 @@ from typing import Union, List, Dict, Optional, Text, Tuple, Any  # noqa: F401
 
 import requests
 
-from pykechain.defaults import API_EXTRA_PARAMS
+from pykechain.defaults import API_EXTRA_PARAMS, PARTS_BATCH_LIMIT
 from pykechain.enums import Category, Multiplicity, Classification, PropertyType
 from pykechain.exceptions import APIError, IllegalArgumentError, NotFoundError, MultipleFoundError
 from pykechain.extra_utils import relocate_model, move_part_instance, relocate_instance, get_mapping_dictionary, \
@@ -112,11 +112,12 @@ class Part(TreeObject, Part2):
     #
 
     def property(self, name: Text = None) -> 'AnyProperty':
-        """Retrieve the property belonging to this part based on its name or uuid.
+        """Retrieve the property belonging to this part based on its name, ref or uuid.
 
-        :param name: property name, ref or property UUID to search for
+        :param name: property name, ref or UUID to search for
         :return: a single :class:`Property`
         :raises NotFoundError: if the `Property` is not part of the `Part`
+        :raises MultipleFoundError
 
         Example
         -------
@@ -135,14 +136,18 @@ class Part(TreeObject, Part2):
 
         """
         if is_uuid(name):
-            found = find(self.properties, lambda p: name == p.id)
+            matches = [p for p in self.properties if p.id == name]
         else:
-            found = find(self.properties, lambda p: name == p.name or name == p.ref)
+            matches = [p for p in self.properties if p.name == name]
+            if not matches:
+                matches = [p for p in self.properties if p.ref == name]
 
-        if not found:
-            raise NotFoundError("Could not find property with name, ref or id '{}'".format(name))
-
-        return found
+        if not matches:
+            raise NotFoundError("Could not find a property with name, id or ref: {}".format(name))
+        elif len(matches) > 1:
+            raise MultipleFoundError("Found multiple properties with name, id or ref: {}".format(name))
+        else:
+            return matches[0]
 
     def scope(self) -> 'Scope':
         """Scope this Part belongs to.
@@ -259,7 +264,7 @@ class Part(TreeObject, Part2):
             raise NotFoundError('{} has no matching child.{}'.format(self, criteria))
         return part
 
-    def populate_descendants(self, batch: int = 200) -> None:
+    def populate_descendants(self, batch: int = PARTS_BATCH_LIMIT) -> None:
         """
         Retrieve the descendants of a specific part in a list of dicts and populate the :func:`Part.children()` method.
 
@@ -272,7 +277,7 @@ class Part(TreeObject, Part2):
         .. versionchanged:: 3.3.2 now populates child parts instead of this part
 
         :param batch: Number of Parts to be retrieved in a batch
-        :type batch: int (defaults to 200)
+        :type batch: int (defaults to 100)
         :returns: None
         :raises APIError: if you cannot create the children tree.
 
@@ -666,7 +671,7 @@ class Part(TreeObject, Part2):
             properties_fvalues: List[Dict[Text, Any]],
             update_dict: Dict,
             creating: bool = False,
-    ) -> Tuple[List[Dict], List[Dict]]:
+    ) -> Tuple[List[Dict], List[Dict], Dict]:
         """
         Check the content of the update dict and insert them into the properties_fvalues list.
 
@@ -685,6 +690,8 @@ class Part(TreeObject, Part2):
 
         key = "model_id" if creating else "id"
 
+        parsed_dict = dict()
+
         for prop_name_or_id, property_value in update_dict.items():
             property_to_update = part.property(prop_name_or_id)  # type: Property
 
@@ -692,13 +699,14 @@ class Part(TreeObject, Part2):
                 "value": property_to_update.serialize_value(property_value),
                 key: property_to_update.id,
             }
+            parsed_dict[property_to_update.id] = property_value
 
             if property_to_update.type == PropertyType.ATTACHMENT_VALUE:
                 exception_fvalues.append(updated_p)
             else:
                 properties_fvalues.append(updated_p)
 
-        return properties_fvalues, exception_fvalues
+        return properties_fvalues, exception_fvalues, parsed_dict
 
     def add_with_properties(self,
                             model: 'Part',
@@ -760,7 +768,7 @@ class Part(TreeObject, Part2):
             raise IllegalArgumentError('`model` must be a Part object of category MODEL, "{}" is not.'.format(model))
 
         instance_name = check_text(name, 'name') or model.name
-        properties_fvalues, exception_fvalues = self._parse_update_dict(
+        properties_fvalues, exception_fvalues, _ = self._parse_update_dict(
             model,
             properties_fvalues,
             update_dict,
@@ -1008,7 +1016,8 @@ class Part(TreeObject, Part2):
         # action = 'bulk_update_properties'  # not for KEC3
         check_text(name, 'name')
 
-        properties_fvalues, exception_fvalues = self._parse_update_dict(self, properties_fvalues, update_dict)
+        properties_fvalues, exception_fvalues, update_dict = \
+            self._parse_update_dict(self, properties_fvalues, update_dict)
 
         payload_json = dict(
             properties_fvalues=properties_fvalues,
@@ -1018,18 +1027,11 @@ class Part(TreeObject, Part2):
         if name:
             payload_json.update(name=name)
 
-        if Property._use_bulk_update and not (name or kwargs):
-            # Use the bulk-update for properties, but only if only properties are being updated, nothing more
-
-            value_dict = dict()
-            for update in properties_fvalues:
-                pk = update.pop("id")
-                value_dict[pk] = update.get("value")
-                Property._update_package[pk] = update
-
+        if Property._USE_BULK_UPDATE and not (name or kwargs):
+            # Send updates to the property value in case of bulk updates while no part update is required
             for prop in self.properties:
-                if prop.id in value_dict:
-                    prop._value = value_dict[prop.id]
+                if prop.id in update_dict:
+                    prop.value = update_dict[prop.id]
         else:
             response = self._client._request(
                 'PUT', self._client._build_url('part', part_id=self.id),
