@@ -442,14 +442,14 @@ class Scope(Base, TagsMixin, Scope2):
 
         See :class:`pykechain.Client.activities` for available parameters.
         """
-        return self._client.activities(*args, scope_id=self.id, **kwargs)
+        return self._client.activities(*args, scope=self.id, **kwargs)
 
     def activity(self, *args, **kwargs) -> 'Activity':
         """Retrieve a single activity belonging to this scope.
 
         See :class:`pykechain.Client.activity` for available parameters.
         """
-        return self._client.activity(*args, scope_id=self.id, **kwargs)
+        return self._client.activity(*args, scope=self.id, **kwargs)
 
     def create_activity(self, *args, **kwargs) -> 'Activity':
         """Create a new activity belonging to this scope.
