@@ -1,6 +1,9 @@
+from typing import Text
+
 import pytz
 
 from .base import Base
+from ..enums import LanguageCodes
 
 
 class User(Base):
@@ -31,7 +34,17 @@ class User(Base):
         return "<pyke {} '{}' id {}>".format(self.__class__.__name__, self.username, self.id)
 
     @property
-    def timezone(self):
+    def default_name(self) -> Text:
+        """
+        Get default name, prioritizing the user name over the KE-chain name.
+
+        :return: Name
+        :rtype str
+        """
+        return self.username if self.username else self.name
+
+    @property
+    def timezone(self) -> pytz.BaseTzInfo:
         """
         Timezone of the user.
 
@@ -44,7 +57,7 @@ class User(Base):
         return pytz.timezone(zone=self._json_data.get('timezone', 'UTC'))
 
     @property
-    def language(self):
+    def language(self) -> Text:
         """
         Language code of the user.
 
@@ -53,10 +66,10 @@ class User(Base):
         :return: language code string
         :rtype: basestring
         """
-        return self._json_data.get('language_code', 'en')
+        return self._json_data.get('language_code', LanguageCodes.ENGLISH)
 
     @property
-    def email(self):
+    def email(self) -> Text:
         """
         Email of the user.
 
