@@ -90,6 +90,9 @@ class TestScopeMembers(TestBetamax):
             'superuser',
             'testlead',
         ],
+        ScopeRoles.SUPERVISOR: [
+            'supervisor'
+        ],
         ScopeRoles.MEMBER: [
             'testuser',
         ]
@@ -99,7 +102,7 @@ class TestScopeMembers(TestBetamax):
         """Reset the scope members by removing all members and adding the defaults"""
         [self.project.remove_member(member=member['username']) for member in self.project.members()]
 
-        for role in [ScopeRoles.MANAGER, ScopeRoles.LEADMEMBER, ScopeRoles.MEMBER]:
+        for role in [ScopeRoles.MANAGER, ScopeRoles.LEADMEMBER, ScopeRoles.MEMBER, ScopeRoles.SUPERVISOR]:
             for member in self.DEFAULTS[role]:
                 self.project._update_scope_project_team(ScopeMemberActions.ADD, role, member)
 
@@ -124,17 +127,17 @@ class TestScopeMembers(TestBetamax):
 
         all_members = set(get_member_names())
         managers = set(get_member_names(is_manager=True))
+        supervisors = set(get_member_names(is_supervisor=True))
         non_managers = set(get_member_names(is_manager=False))
         leads = set(get_member_names(is_leadmember=True))
         non_leads = set(get_member_names(is_leadmember=False))
         basic_members = set(get_member_names(is_manager=False, is_leadmember=False))
-        lead_and_manager = set(get_member_names(is_manager=True, is_leadmember=True))
 
-        self.assertEqual(4, len(all_members), msg=','.join(all_members))
-        self.assertTrue(basic_members and leads and managers and lead_and_manager,
+        self.assertEqual(5, len(all_members), msg=','.join(all_members))
+        self.assertTrue(basic_members and leads and managers and supervisors,
                         msg='Test scope must have a member of every type!')
 
-        all_roles = basic_members | leads | managers | lead_and_manager
+        all_roles = basic_members | leads | managers | supervisors
         remaining_non_leads = all_roles - leads
         remaining_non_managers = all_roles - managers
 
@@ -142,9 +145,6 @@ class TestScopeMembers(TestBetamax):
         self.assertSetEqual(remaining_non_leads, non_leads)
         self.assertSetEqual(remaining_non_managers, non_managers)
 
-        self.assertTrue(lead_and_manager <= managers)
-        self.assertTrue(lead_and_manager <= leads)
-
     def test_add_member(self):
         member_to_be_added = 'anotheruser'
         self.project.add_member(member_to_be_added)
@@ -215,6 +215,24 @@ class TestScopeMembers(TestBetamax):
         project_leadmembers = self.project.members(is_leadmember=False)
         self.assertTrue(leadmember_to_be_removed in [leadmember['username'] for leadmember in project_leadmembers])
 
+    def test_add_supervisor(self):
+        supervisor_to_be_added = 'anotheruser'
+        # testing
+        self.project.add_supervisor(supervisor_to_be_added)
+        self.project = self.client.scope(pk=self.project.id)
+        project_supervisors = self.project.members(is_supervisor=True)
+        self.assertTrue(supervisor_to_be_added in [supervisor['username'] for supervisor in project_supervisors])
+
+    def test_remove_supervisor(self):
+        supervisor_to_be_removed = 'anotheruser'
+        # setUp
+        self.project.add_supervisor(supervisor_to_be_removed)
+        # testing
+        self.project.remove_supervisor(supervisor_to_be_removed)
+        self.project = self.client.scope(pk=self.project.id)
+        project_supervisors = self.project.members(is_supervisor=True)
+        self.assertTrue(supervisor_to_be_removed not in [supervisor['username'] for supervisor in project_supervisors])
+
 
 class TestScopeEdit(TestBetamax):
     """
@@ -252,7 +270,7 @@ class TestScopeEdit(TestBetamax):
         )
 
         retrieved_project = self.client.scope(id=self.scope.id, status=ScopeStatus.CLOSED)
-        
+
         # testing
         self.assertEqual(new_scope_name, retrieved_project.name)
         self.assertEqual(new_scope_description, retrieved_project.description)
@@ -279,6 +297,56 @@ class TestScopeEdit(TestBetamax):
         with self.assertRaises(IllegalArgumentError):
             self.scope.edit(tags='tags must be a list of strings')
 
+    # test added due to #847 - providing no inputs overwrites values
+    def test_edit_scope_clearing_values(self):
+        # setUp
+        initial_name = 'Pykechain testing (bike project)'
+        initial_description = 'Project used to build a Bike. Part-time job is to also test Pykechain.'
+        initial_start_date = datetime.datetime(2018, 12, 5, tzinfo=None)
+        initial_due_date = datetime.datetime(2018, 12, 8, tzinfo=None)
+        initial_tags = ['tag_one', 'tag_two']
+        team_one, team_two = self.client.teams()[:2]
+
+        self.scope.edit(
+            name=initial_name,
+            description=initial_description,
+            start_date=initial_start_date,
+            due_date=initial_due_date,
+            tags=initial_tags,
+            team=team_two
+        )
+
+        # Edit without mentioning values, everything should stay the same
+        new_name = 'Just Pykechain testing (bike project)'
+        self.scope.edit(
+            name=new_name
+        )
+
+        # testing
+        self.assertEqual(self.scope.name, new_name)
+        self.assertEqual(self.scope.description, initial_description)
+        self.assertEqual(self.scope.start_date.strftime("%Y/%m/%d, %H:%M:%S"),
+                         initial_start_date.strftime("%Y/%m/%d, %H:%M:%S"))
+        self.assertEqual(self.scope.due_date.strftime("%Y/%m/%d, %H:%M:%S"),
+                         initial_due_date.strftime("%Y/%m/%d, %H:%M:%S"))
+        self.assertEqual(self.scope.tags, initial_tags)
+
+        # Edit with clearing the values, name and status cannot be cleared
+        self.scope.edit(
+            name=None,
+            description=None,
+            start_date=None,
+            due_date=None,
+            status=None,
+            tags=None
+        )
+        self.scope.refresh()
+        self.assertEqual(self.scope.name, new_name)
+        self.assertEqual(self.scope.description, str())
+        self.assertEqual(self.scope.start_date, None)
+        self.assertEqual(self.scope.due_date, None)
+        self.assertEqual(self.scope.tags, list())
+
     # v2.3.3
     def test_edit_scope_team(self):
         """Test capabilities of changing team scope"""
