@@ -24,7 +24,7 @@ class TestServiceSetup(TestBetamax):
         new_service = self.project.create_service(
             name=name or 'Test upload script to service',
             description="Only used for testing - you can safely remove this",
-            environment_version=ServiceEnvironmentVersion.PYTHON_3_6,
+            environment_version=ServiceEnvironmentVersion.PYTHON_3_8,
         )
         upload_path = os.path.join(self.test_assets_dir, 'tests', 'files', 'test_upload_script_to_service',
                                    'test_upload_script.py')
@@ -152,7 +152,9 @@ class TestServices(TestBetamax):
         initial_run_as = 'kenode'
         initial_trusted = False
         initial_type = ServiceType.NOTEBOOK
-        initial_env = ServiceEnvironmentVersion.PYTHON_3_7_NOTEBOOKS
+        initial_env = ServiceEnvironmentVersion.PYTHON_3_8_NOTEBOOKS
+        # TODO: to be removed in later versions of pykechain, only for temporal compatibility
+        compatibility_env = "3.7_notebook"
 
         self.service = self.project.create_service(name=initial_name)
 
@@ -179,7 +181,7 @@ class TestServices(TestBetamax):
         self.assertEqual(self.service.version, initial_version)
         self.assertEqual(self.service.run_as, initial_run_as)
         self.assertEqual(self.service.type, initial_type)
-        self.assertEqual(self.service.environment, initial_env)
+        self.assertIn(self.service.environment, (initial_env, compatibility_env))
         self.assertEqual(self.service.trusted, initial_trusted)
 
         # Edit with clearing the values, name and status cannot be cleared
@@ -197,7 +199,7 @@ class TestServices(TestBetamax):
         self.assertEqual(self.service.description, str())
         self.assertEqual(self.service.version, str())
         self.assertEqual(self.service.type, initial_type)
-        self.assertEqual(self.service.environment, initial_env)
+        self.assertIn(self.service.environment, (initial_env, compatibility_env))
         self.assertEqual(self.service.run_as, initial_run_as)
         self.assertEqual(self.service.trusted, initial_trusted)
 
