@@ -4,8 +4,10 @@ from pykechain.enums import (WidgetTypes, ShowColumnTypes, FilterType, ProgressB
                              Category, LinkTargets, KEChainPages, WidgetTitleValue, Alignment, ActivityType,
                              CardWidgetLinkValue, CardWidgetLinkTarget, ImageFitValue, PropertyType, Classification,
                              Multiplicity)
-from pykechain.models.widgets.enums import DashboardWidgetSourceScopes, DashboardWidgetShowTasks, \
-    DashboardWidgetShowScopes
+from pykechain.models.widgets.enums import (
+    DashboardWidgetShowTasks,
+    DashboardWidgetShowScopes,
+)
 from pykechain.exceptions import IllegalArgumentError, NotFoundError
 from pykechain.models import Activity, Part
 from pykechain.models.widgets import (
@@ -154,6 +156,26 @@ class TestWidgets(TestBetamax):
         self.assertTrue(all(p.category == Category.MODEL for p in models))
         self.assertTrue(all(p.category == Category.INSTANCE for p in models))
 
+    def test_bulk_update(self):
+        parent = self.project.activity(name="Tasks with Widgets")
+        task = self.project.activity(name="Task - Form + Tables + Service")
+        test_task = task.clone(
+            parent=parent,
+            name="BULK WIDGET TEST TASK",
+        )
+        self.new_widget = test_task  # for teardown
+
+        widgets = list(test_task.widgets())[1:]  # remove meta-panel
+        self.client.update_widgets(
+            widgets=[dict(id=w.id, title="widget {}".format(i + 1)) for i, w in enumerate(widgets)]
+        )
+
+        with self.assertRaises(IllegalArgumentError):
+            double_update = [widgets[0], widgets[0], widgets[1]]
+            self.client.update_widgets(
+                widgets=[dict(id=w.id, title="widget {}".format(i + 1)) for i, w in enumerate(double_update)]
+            )
+
 
 class TestWidgetManager(TestBetamax):
 
@@ -246,6 +268,49 @@ class TestWidgetManagerInActivity(TestBetamax):
         self.assertEqual(new_title, live_widget.title)
         self.assertEqual(new_title, live_widget.title_visible)
 
+    def test_edit_widget_title_is_none(self):
+        bike_part = self.project.part('Bike')
+        widget = self.wm.add_propertygrid_widget(
+            part_instance=bike_part,
+            writable_models=bike_part.model().properties,
+        )
+
+        widget.edit(title=None)
+
+        live_widget = self.client.widget(pk=widget.id)
+
+        self.assertFalse(live_widget.title)
+        self.assertIsNone(live_widget.title_visible)
+        self.assertEqual(WidgetTitleValue.NO_TITLE, live_widget.meta.get("showTitleValue"))
+
+        widget.edit(title=False)
+
+        live_widget = self.client.widget(pk=widget.id)
+
+        self.assertFalse(live_widget.title)
+        self.assertEqual("Bike", live_widget.title_visible)
+        self.assertEqual(WidgetTitleValue.DEFAULT, live_widget.meta.get("showTitleValue"))
+
+    def test_edit_widget_title_and_meta(self):
+        bike_part = self.project.part('Bike')
+        widget = self.wm.add_propertygrid_widget(
+            part_instance=bike_part,
+            writable_models=bike_part.model().properties,
+        )
+        new_title = "New title"
+        new_meta = dict(widget.meta)
+        new_meta.update({"showColumns": [ShowColumnTypes.UNIT, ShowColumnTypes.DESCRIPTION]})
+        widget.edit(
+            title=new_title,
+            meta=new_meta,
+        )
+
+        live_widget = self.client.widget(pk=widget.id)
+
+        self.assertEqual(new_title, live_widget.title)
+        self.assertEqual(new_title, live_widget.title_visible)
+        self.assertEqual([ShowColumnTypes.UNIT, ShowColumnTypes.DESCRIPTION], live_widget.meta["showColumns"])
+
     def test_widget_title(self):
         title = 'Hidden title'
         bike_part = self.project.part('Bike')
